"""
maix.camera module, access camera device and get image from it
"""
from __future__ import annotations
import maix._maix.err
import maix._maix.image
__all__ = ['Camera', 'list_devices', 'set_regs_enable']
class Camera:
    def __init__(self, width: int = -1, height: int = -1, format: maix._maix.image.Format = ..., device: str = None, fps: int = -1, buff_num: int = 3, open: bool = True) -> None:
        ...
    def add_channel(self, width: int = -1, height: int = -1, format: maix._maix.image.Format = ..., fps: int = -1, buff_num: int = 3, open: bool = True) -> Camera:
        """
        Add a new channel and return a new Camera object, you can use close() to close this channel.
        
        Args:
          - width: camera width, default is -1, means auto, mostly means max width of camera support
          - height: camera height, default is -1, means auto, mostly means max height of camera support
          - format: camera output format, default is RGB888
          - fps: camera fps, default is -1, means auto, mostly means max fps of camera support
          - buff_num: camera buffer number, default is 3, means 3 buffer, one used by user, one used for cache the next frame,
        more than one buffer will accelerate image read speed, but will cost more memory.
          - open: If true, camera will automatically call open() after creation. default is true.
        
        
        Returns: new Camera object
        """
    def buff_num(self) -> int:
        """
        Get camera buffer number
        
        Returns: camera buffer number
        """
    def clear_buff(self) -> None:
        """
        Clear buff to ensure the next read image is the latest image
        """
    def close(self) -> None:
        """
        Close camera
        """
    def device(self) -> str:
        """
        Get camera device path
        
        Returns: camera device path
        """
    def exposure(self, value: int = -1) -> float:
        """
        Get camera exposure
        
        Returns: camera exposure
        """
    def format(self) -> maix._maix.image.Format:
        """
        Get camera output format
        
        Returns: camera output format, image::Format object
        """
    def fps(self) -> int:
        """
        Get camera fps
        
        Returns: camera fps
        """
    def gain(self, value: int = -1) -> float:
        """
        Get camera gain
        
        Returns: camera gain
        """
    def get_ch_nums(self) -> int:
        """
        Get the number of channels supported by the camera.
        
        Returns: Returns the maximum number of channels.
        """
    def height(self) -> int:
        """
        Get camera height
        
        Returns: camera height
        """
    def hmirror(self, value: int = -1) -> int:
        """
        Get camera horizontal mirror
        
        Returns: camera horizontal mirror
        """
    def is_closed(self) -> bool:
        """
        check camera device is closed or not
        
        Returns: closed or not, bool type
        """
    def is_opened(self) -> bool:
        """
        Check if camera is opened
        
        Returns: true if camera is opened, false if not
        """
    def open(self, width: int = -1, height: int = -1, format: maix._maix.image.Format = ..., fps: int = -1, buff_num: int = -1) -> maix._maix.err.Err:
        """
        Open camera and run
        
        Args:
          - width: camera width, default is -1, means auto, mostly means max width of camera support
          - height: camera height, default is -1, means auto, mostly means max height of camera support
          - format: camera output format, default is RGB888
          - fps: camera fps, default is -1, means auto, mostly means max fps of camera support
          - buff_num: camera buffer number, default is 3, means 3 buffer, one used by user, one used for cache the next frame,
        more than one buffer will accelerate image read speed, but will cost more memory.
        
        
        Returns: error code, err::ERR_NONE means success, others means failed
        """
    def read(self, buff: capsule = None, block: bool = True) -> maix._maix.image.Image:
        """
        Get one frame image from camera buffer, must call open method before read.
        If open method not called, will call it automatically, if open failed, will throw exception!
        So call open method before read is recommended.
        
        Args:
          - buff: buffer to store image data, if buff is nullptr, will alloc memory automatically.
        In MaixPy, default to None, you can create a image.Image object, then pass img.data() to buff.
          - block: block read, default is true, means block util read image successfully,
        if set to false, will return nullptr if no image in buffer
        
        
        Returns: image::Image object, if failed, return nullptr, you should delete if manually in C++
        """
    def read_reg(self, addr: int, bit_width: int = 8) -> int:
        """
        Read camera register
        
        Args:
          - addr: register address
          - bit_width: register data bit width, default is 8
        
        
        Returns: register data, -1 means failed
        """
    def show_colorbar(self, enable: bool) -> maix._maix.err.Err:
        """
        Camera output color bar image for test
        
        Args:
          - enable: enable/disable color bar
        
        
        Returns: error code, err::ERR_NONE means success, others means failed
        """
    def vflip(self, value: int = -1) -> int:
        """
        Get camera vertical flip
        
        Returns: camera vertical flip
        """
    def width(self) -> int:
        """
        Get camera width
        
        Returns: camera width
        """
    def write_reg(self, addr: int, data: int, bit_width: int = 8) -> maix._maix.err.Err:
        """
        Write camera register
        
        Args:
          - addr: register address
          - data: register data
          - bit_width: register data bit width, default is 8
        
        
        Returns: error code, err::ERR_NONE means success, others means failed
        """
def list_devices() -> list[str]:
    """
    List all supported camera devices.
    
    Returns: Returns the path to the camera device.
    """
def set_regs_enable(enable: bool = True) -> None:
    """
    Enable set camera registers, default is false, if set to true, will not set camera registers, you can manually set registers by write_reg API.
    
    Args:
      - enable: enable/disable set camera registers
    """
